@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_master - remote control master for Nokia N900 phone #
-# $Id: smscon_master.py 30 2011-12-17 22:50:34Z yablacky $
+# $Id: smscon_master.py 33 2011-12-17 23:50:16Z yablacky $
 ##############################################################
 
 import os
@@ -107,6 +107,7 @@ def ShowOptions(Level = 1):
         print '   -unboot            : Disable %s to start at phone boot' % DaemonFile
         print '   -add imsi          : Add IMSI code of current SIM to %s file' % CodeDisplayName
         print '   -remove imsi       : Remove IMSI code of current SIM from %s file' % CodeDisplayName
+        print '   -version           : Show version number'    
         print '   -help              : This help menu'
         print '   -help2             : More help (special options, rarely used).'
     if Level >= 2:
@@ -136,9 +137,8 @@ def ShowHiddenOptions():
     """
     print ' Developer options:'
     print '   -devhelp           : This extended help menu'
-    print '   -branch            : Show branch number'
-    print '   -build             : Show build number'
-    print '   -version           : Show full version number'    
+    print '   -branch            : Show branch number. Deprecated. Removed in future. Shows -version now.'
+    print '   -build             : Show build number.  Deprecated. Removed in future. Shows -version now.'
     print '   -init!             : Create default %s files. Do not upgrade existing ones.' % ' & '.join((ConfigDisplayName, ScriptDisplayName))
     print '   -get name "default": Get user setting'
     print '   -test "test"       : Run developer test (gps1, gps2, ssh, ssh-off, cam, sms, email1, email2, call, script)'
@@ -176,8 +176,8 @@ def DoCommandLine():
         elif Mode == '-help2':      ShowOptions(2) 
         elif Mode == '-devhelp':    ShowOptions(2); ShowHiddenOptions()
         elif Mode == '-version':    print VERSION        
-        elif Mode == '-branch':     print BRANCH
-        elif Mode == '-build':      print BUILD
+        elif Mode == '-branch':     print VERSION
+        elif Mode == '-build':      print VERSION
         elif Mode == '-status':     print "Daemon %s is %s" % (DaemonFile, IF(daemon.runs(), 'running', 'off'))
         elif Mode == '-log':        ok = ShowFile(LOGGER.LogFilename)    
         elif Mode == '-imsi':       ok = ShowIMSICodes()
